@@ -1,6 +1,5 @@
 import atexit
 import time
-from subprocess import PIPE, Popen
 from threading import Thread, Event
 
 import numpy as np
@@ -8,7 +7,7 @@ import pyaudio
 import tflit
 from pyaudio import PyAudio, paInt16
 
-from precise_lite_runner.params import inject_params, pr
+from precise_lite_runner.params import params
 from precise_lite_runner.util import buffer_to_audio, ThresholdDecoder
 from precise_lite_runner.vectorization import vectorize_raw, add_deltas
 
@@ -56,16 +55,15 @@ class Listener:
 
     def __init__(self, model_name: str, chunk_size: int = -1):
         self.window_audio = np.array([])
-        self.pr = inject_params(model_name)
-        self.mfccs = np.zeros((self.pr.n_features, self.pr.n_mfcc))
+        self.mfccs = np.zeros((params.n_features, params.n_mfcc))
         self.chunk_size = chunk_size
         self.runner = TFLiteRunner(model_name)
-        self.threshold_decoder = ThresholdDecoder(self.pr.threshold_config,
-                                                  pr.threshold_center)
+        self.threshold_decoder = ThresholdDecoder(params.threshold_config,
+                                                  params.threshold_center)
 
     def clear(self):
         self.window_audio = np.array([])
-        self.mfccs = np.zeros((self.pr.n_features, self.pr.n_mfcc))
+        self.mfccs = np.zeros((params.n_features, params.n_mfcc))
 
     def update_vectors(self, stream):
         if isinstance(stream, np.ndarray):
@@ -81,10 +79,10 @@ class Listener:
 
         self.window_audio = np.concatenate((self.window_audio, buffer_audio))
 
-        if len(self.window_audio) >= self.pr.window_samples:
+        if len(self.window_audio) >= params.window_samples:
             new_features = vectorize_raw(self.window_audio)
             self.window_audio = self.window_audio[
-                                len(new_features) * self.pr.hop_samples:]
+                                len(new_features) * params.hop_samples:]
             if len(new_features) > len(self.mfccs):
                 new_features = new_features[-len(self.mfccs):]
             self.mfccs = np.concatenate(
@@ -94,64 +92,13 @@ class Listener:
 
     def update(self, stream):
         mfccs = self.update_vectors(stream)
-        if self.pr.use_delta:
+        if params.use_delta:
             mfccs = add_deltas(mfccs)
         raw_output = self.runner.run(mfccs)
         return self.threshold_decoder.decode(raw_output)
 
-
-class Engine:
-    def __init__(self, chunk_size=2048):
-        self.chunk_size = chunk_size
-
-    def start(self):
-        pass
-
-    def stop(self):
-        pass
-
     def get_prediction(self, chunk):
-        raise NotImplementedError
-
-
-class PreciseEngine(Engine):
-    """
-    Wraps a binary precise executable
-
-    Args:
-        exe_file (Union[str, list]): Either filename or list of arguments
-                                     (ie. ['python', 'precise/scripts/engine.py'])
-        model_file (str): Location to .pb model file to use (with .pb.params)
-        chunk_size (int): Number of *bytes* per prediction. Higher numbers
-                          decrease CPU usage but increase latency
-    """
-
-    def __init__(self, exe_file, model_file, chunk_size=2048):
-        Engine.__init__(self, chunk_size)
-        self.exe_args = exe_file if isinstance(exe_file, list) else [exe_file]
-        self.exe_args += [model_file, str(self.chunk_size)]
-        self.proc = None
-
-    def start(self):
-        self.proc = Popen(self.exe_args, stdin=PIPE, stdout=PIPE)
-
-    def stop(self):
-        if self.proc:
-            self.proc.kill()
-            self.proc = None
-
-    def get_prediction(self, chunk):
-        if len(chunk) != self.chunk_size:
-            raise ValueError('Invalid chunk size: ' + str(len(chunk)))
-        self.proc.stdin.write(chunk)
-        self.proc.stdin.flush()
-        return float(self.proc.stdout.readline())
-
-
-class ListenerEngine(Engine):
-    def __init__(self, listener, chunk_size=2048):
-        Engine.__init__(self, chunk_size)
-        self.get_prediction = listener.update
+        return self.update(chunk)
 
 
 class ReadWriteStream:
@@ -227,17 +174,8 @@ class TriggerDetector:
 
 class PreciseRunner:
     """
-    Wrapper to use Precise. Example:
-    >>> def on_act():
-    ...     print('Activation!')
-    ...
-    >>> p = PreciseRunner(PreciseEngine('./precise-engine'), on_activation=on_act)
-    >>> p.start()
-    >>> from time import sleep; sleep(10)
-    >>> p.stop()
-
     Args:
-        engine (Engine): Object containing info on the binary engine
+        listener (Listener):
         trigger_level (int): Number of chunk activations needed to trigger on_activation
                        Higher values add latency but reduce false positives
         sensitivity (float): From 0.0 to 1.0, how sensitive the network should be
@@ -247,19 +185,18 @@ class PreciseRunner:
         on_activation (Callable): callback for when the wake word is heard
     """
 
-    def __init__(self, engine, trigger_level=3, sensitivity=0.5, stream=None,
+    def __init__(self, listener, trigger_level=3, sensitivity=0.5, stream=None,
                  on_prediction=lambda x: None, on_activation=lambda: None):
-        self.engine = engine
+        self.listener = listener
         self.trigger_level = trigger_level
         self.stream = stream
         self.on_prediction = on_prediction
         self.on_activation = on_activation
-        self.chunk_size = engine.chunk_size
+        self.chunk_size = self.listener.chunk_size
 
         self.pa = None
         self.thread = None
         self.running = False
-        self.is_paused = False
         self.detector = TriggerDetector(self.chunk_size, sensitivity,
                                         trigger_level)
         atexit.register(self.stop)
@@ -283,9 +220,7 @@ class PreciseRunner:
 
         self._wrap_stream_read(self.stream)
 
-        self.engine.start()
         self.running = True
-        self.is_paused = False
         self.thread = Thread(target=self._handle_predictions, daemon=True)
         self.thread.daemon = True
         self.thread.start()
@@ -299,29 +234,18 @@ class PreciseRunner:
             self.thread.join()
             self.thread = None
 
-        self.engine.stop()
-
         if self.pa:
             self.pa.terminate()
             self.stream.stop_stream()
             self.stream = self.pa = None
 
-    def pause(self):
-        self.is_paused = True
-
-    def play(self):
-        self.is_paused = False
-
     def _handle_predictions(self):
         """Continuously check Precise process output"""
         while self.running:
             # t0 = time.time()
             chunk = self.stream.read(self.chunk_size)
 
-            if self.is_paused:
-                continue
-
-            prob = self.engine.get_prediction(chunk)
+            prob = self.listener.get_prediction(chunk)
             self.on_prediction(prob)
             if self.detector.update(prob):
                 self.on_activation()
